/*

 path.h - A mostly working PCLink server for IDEDOS 0.9x

 Written by
  Kajtar Zsolt <soci@c64.rulez.org>

    This file is part of IDEDOS the IDE64 disk operating system
    See README for copyright notice.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef _PATH_H
#define _PATH_H
#include <wchar.h>
#include "nameconversion.h"
#include "petscii.h"

typedef struct Path {
    size_t len;
    size_t max;
    size_t root;
    char *data;
} Path;

#define MAX_C64NAME_LEN (16+1+3+1)

struct Partition;

extern const char *path_new(Path *, const char *, size_t);
extern void path_reset(Path *);
extern void path_free(Path *);
extern const char *path_append(Path *, const char *);
extern void path_root(Path *);
extern const char *path_parent(Path *);
extern void convertfilename(const Petscii *, char, Petscii *, Petscii *, Petscii *);
extern const char *path_appendc64(Path *, const Petscii *);
extern int invalid_c64name(Petscii *);
extern int matchname(Petscii *, Petscii *);
extern const Petscii *resolv_part(const Petscii *, Path *, struct Partition **, int);
extern const Petscii *resolv_path(const Petscii *, Path *, Nameconversion);
extern void convertc64name(Petscii[MAX_C64NAME_LEN], const Petscii *, const Petscii *, Nameconversion);
#endif
